@@ -11,9 +11,11 @@
 #include <QDesktopServices>
 #include <QShortcut>
 #include <QUrl>
+#include <QFile>
 #include <QFileInfo>
 #include <QSettings>
 #include <QString>
+#include <QTextStream>
 #include <QMaemo5InformationBox>
 #include <QtMaemo5/QtMaemo5>
 
@@ -247,11 +249,24 @@ void MainWindow::disableStatus()
    {
         ui->pushButtonEject->setDisabled(true);
         ui->pushButtonSwapUsage->setDisabled(true);
+        ui->labelStat->setText("Safe to Remove Back Cover");
    }
  else
    {
         ui->pushButtonEject->setDisabled(false);
         ui->pushButtonSwapUsage->setDisabled(false);
+          if ( QFileInfo("/tmp/flopswapcur").exists() )
+          {
+              QFile file("/tmp/flopswapcur");
+              file.open(QIODevice::ReadOnly | QIODevice::Text);
+              QTextStream in(&file);
+              QString line = in.readLine();
+              ui->labelStat->setText(line);
+          }
+          else
+          {
+              ui->labelStat->setText("Initialized...");
+          }
    }
 }
 
