@@ -66,6 +66,11 @@ private slots:
 
     void disableStatus();
 
+    void swappingActive();
+
+    void disableButtons();
+
+    void enableButtons();
 
 private:
     Ui::MainWindow *ui;
@@ -74,7 +79,6 @@ private:
     Instructions *instructions;
     Settings *settingspage;
     QProcess *m_process;
-
 };
 
 #endif // MAINWINDOW_H
