@@ -42,6 +42,8 @@ xswapoff="/bin/busybox swapoff"
 #Temporary file locations
 tempfile=/tmp/flopswaplast
 inttempfile=/tmp/flopswapint
+swaptempfile=/tmp/flopswapref
+latesttempfile=/tmp/flopswapcur
 
 # Setup notification
 r=run-standalone.sh
