@@ -83,7 +83,7 @@ echo $getpercent % Fresh Swap Written
 banner "$getpercent % Fresh Swap Written
 $getcurrent Mb of $swapsizembytes Mb"
 #Print to file
-echo "$getcurrent Mb $getpercent % of $swapsizembytes Mb" > "$latesttempfile"
+echo "$getpercent % ($getcurrent Mb of $swapsizembytes Mb)" > "$latesttempfile"
 #If 94% show warning dialog
 if [ $getpercent -ge $psb ]; then
 dialog "
